@@ -1,7 +1,6 @@
 package Parse::BBCode::HTML;
 use strict;
 use warnings;
-use Data::Dumper;
 use Carp qw(croak carp);
 use URI::Escape;
 use base 'Exporter';
@@ -16,23 +15,23 @@ eval {
 $email_valid = 1 unless $@;
 
 my %colors = (
-    aqua    => 1,                                                                  
-    black   => 1,                                                                  
-    blue    => 1,                                                                  
-    fuchsia => 1,                                                                  
-    gray    => 1,                                                                  
-    grey    => 1,                                                                  
-    green   => 1,                                                                  
-    lime    => 1,                                                                  
-    maroon  => 1,                                                                  
-    navy    => 1,                                                                  
-    olive   => 1,                                                                  
-    purple  => 1,                                                                  
-    red     => 1,                                                                  
-    silver  => 1,                                                                  
-    teal    => 1,                                                                  
-    white   => 1,                                                                  
-    yellow  => 1,                                                                  
+    aqua    => 1,
+    black   => 1,
+    blue    => 1,
+    fuchsia => 1,
+    gray    => 1,
+    grey    => 1,
+    green   => 1,
+    lime    => 1,
+    maroon  => 1,
+    navy    => 1,
+    olive   => 1,
+    purple  => 1,
+    red     => 1,
+    silver  => 1,
+    teal    => 1,
+    white   => 1,
+    yellow  => 1,
 );
 
 my %default_tags = (
@@ -170,7 +169,9 @@ sub default_escapes {
 
 sub optional {
     my ($class, @keys) = @_;
-    return @keys ? (grep defined, @optional_tags{@keys}) : %optional_tags;
+    return @keys
+        ? (map { $_ => $optional_tags{$_} } grep  { defined $optional_tags{$_} } @keys)
+        : %optional_tags;
 }
 
 
